#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 constraints
version:              0.14.4
visibility:           public
id:                   constraints-0.14.4-Ak7wGLxuZcs5Ij2hS6MgmA
key:                  constraints-0.14.4-Ak7wGLxuZcs5Ij2hS6MgmA
license:              BSD-2-Clause
copyright:            Copyright (C) 2011-2021 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/constraints/
synopsis:             Constraint manipulation
description:
    GHC 7.4 gave us the ability to talk about @ConstraintKinds@. They stopped crashing the compiler in GHC 7.6.

    This package provides a vocabulary for working with them.

category:             Constraints
abi:                  8188b7f1fbd562056dce3311b52e3741
exposed:              True
exposed-modules:
    Data.Constraint Data.Constraint.Char Data.Constraint.Deferrable
    Data.Constraint.Forall Data.Constraint.Lifting Data.Constraint.Nat
    Data.Constraint.Symbol Data.Constraint.Unsafe

import-dirs:          /usr/lib/ghc-9.6.6/site-local/constraints-0.14.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/constraints-0.14.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/constraints-0.14.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-constraints
hs-libraries:         HSconstraints-0.14.4-Ak7wGLxuZcs5Ij2hS6MgmA
depends:
    base-4.18.2.1 binary-0.8.9.1 boring-0.2.2-95zAwRwmONjM683l7QC17
    deepseq-1.4.8.1 hashable-1.4.7.0-A1kp0rRlB2mBNtk1x2NHGT mtl-2.3.1
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-constraints/html/constraints.haddock
haddock-html:         /usr/share/doc/haskell-constraints/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

